cmoncrawl.processor.pipeline.extractor.BaseExtractor.filter\_raw
================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: BaseExtractor.filter_raw